" Vim Keymap file for ukrainian characters, layout 'dvorak',
" MS Windows variant
" Derived from ukrainian-jcuken.vim by Anatoli Sakhnik <sakhnik@gmail.com>
" Useful mainly with utf-8 but may work with other encodings

" Maintainer:   Serhiy Boiko <cris.kiev@gmail.com>
" Last Changed: 2007 Jun 29

" All characters are given literally, conversion to another encoding (e.g.,
" UTF-8) should work.
scriptencoding utf-8

let b:keymap_name = "uk"

loadkeymap
~	~	CYRILLIC CAPITAL LETTER IO
`	'	CYRILLIC SMALL LETTER IO
U	А	CYRILLIC CAPITAL LETTER A
W	Б	CYRILLIC CAPITAL LETTER BE
E	В	CYRILLIC CAPITAL LETTER VE
G	Г	CYRILLIC CAPITAL LETTER GHE
N	Д	CYRILLIC CAPITAL LETTER DE
Y	Е	CYRILLIC CAPITAL LETTER IE
S	Ж	CYRILLIC CAPITAL LETTER ZHE
L	З	CYRILLIC CAPITAL LETTER ZE
X	И	CYRILLIC CAPITAL LETTER I
\"	Й	CYRILLIC CAPITAL LETTER SHORT I
P	К	CYRILLIC CAPITAL LETTER KA
T	Л	CYRILLIC CAPITAL LETTER EL
K	М	CYRILLIC CAPITAL LETTER EM
F	Н	CYRILLIC CAPITAL LETTER EN
H	О	CYRILLIC CAPITAL LETTER O
I	П	CYRILLIC CAPITAL LETTER PE
D	Р	CYRILLIC CAPITAL LETTER ER
J	С	CYRILLIC CAPITAL LETTER ES
B	Т	CYRILLIC CAPITAL LETTER TE
>	У	CYRILLIC CAPITAL LETTER U
A	Ф	CYRILLIC CAPITAL LETTER EF
?	Х	CYRILLIC CAPITAL LETTER HA
<	Ц	CYRILLIC CAPITAL LETTER TSE
Q	Ч	CYRILLIC CAPITAL LETTER CHE
C	Ш	CYRILLIC CAPITAL LETTER SHA
R	Щ	CYRILLIC CAPITAL LETTER SHCHA
+	Ї	CYRILLIC CAPITAL LETTER YI
O	І	CYRILLIC CAPITAL LETTER BYELORUSSION-UKRAINIAN I
M	Ь	CYRILLIC CAPITAL LETTER SOFT SIGN
_	Є	CYRILLIC CAPITAL LETTER UKRAINIAN IE
V	Ю	CYRILLIC CAPITAL LETTER YU
:	Я	CYRILLIC CAPITAL LETTER YA
|	Ґ	CYRILLIC CAPITAL LETTER GHE WITH UPTURN
u	а	CYRILLIC SMALL LETTER A
w	б	CYRILLIC SMALL LETTER BE
e	в	CYRILLIC SMALL LETTER VE
g	г	CYRILLIC SMALL LETTER GHE
n	д	CYRILLIC SMALL LETTER DE
y	е	CYRILLIC SMALL LETTER IE
s	ж	CYRILLIC SMALL LETTER ZHE
l	з	CYRILLIC SMALL LETTER ZE
x	и	CYRILLIC SMALL LETTER I
'	й	CYRILLIC SMALL LETTER SHORT I
p	к	CYRILLIC SMALL LETTER KA
t	л	CYRILLIC SMALL LETTER EL
k	м	CYRILLIC SMALL LETTER EM
f	н	CYRILLIC SMALL LETTER EN
h	о	CYRILLIC SMALL LETTER O
i	п	CYRILLIC SMALL LETTER PE
d	р	CYRILLIC SMALL LETTER ER
j	с	CYRILLIC SMALL LETTER ES
b	т	CYRILLIC SMALL LETTER TE
.	у	CYRILLIC SMALL LETTER U
a	ф	CYRILLIC SMALL LETTER EF
/	х	CYRILLIC SMALL LETTER HA
,	ц	CYRILLIC SMALL LETTER TSE
q	ч	CYRILLIC SMALL LETTER CHE
c	ш	CYRILLIC SMALL LETTER SHA
r	щ	CYRILLIC SMALL LETTER SHCHA
=	ї	CYRILLIC SMALL LETTER YI
o	і	CYRILLIC SMALL LETTER BYELORUSSION-UKRAINIAN I
m	ь	CYRILLIC SMALL LETTER SOFT SIGN
-	є	CYRILLIC SMALL LETTER UKRAINIAN IE
v	ю	CYRILLIC SMALL LETTER YU
;	я	CYRILLIC SMALL LETTER YA
\\	ґ	CYRILLIC SMALL LETTER GHE WITH UPTURN
@	"
#	№	NUMERO SIGN
$	;
^	:
&	?
z	.
Z	,
[   -
]   =
