" Vim keymap file for Georgian (Mkhedruli) layout
" Maintainer: Mishiko Okropiridze <misho.okropiridze@gmail.com>
" Last changed: 2024-06-14


let b:keymap_name = "ge"

loadkeymap
a ა
A ა
b ბ
c ც
C ჩ
d დ
e ე
E ე
f ფ
F ფ
g გ
G გ
h ჰ
H ჵ
i ი
I ი
j ჯ
J ჟ
k კ
l ლ
m მ
n ნ
o ო
p პ
q ქ
Q ქ
r რ
R ღ
s ს
S შ
t ტ
T თ
u უ
v ვ
V ვ
w წ
W ჭ
x ხ
X ხ
y ყ
Y ყ
z ზ
Z ძ
